@@ -15,8 +15,8 @@ depends() {
 install() {
     declare moddir=${moddir}
     inst_multiple \
-        blkid blockdev parted dd mkdir rmdir \
-        grep cut tail head tr bc true false \
+        blkid blockdev dd mkdir rmdir \
+        grep cut tail head tr bc true false mountpoint \
         basename partprobe sfdisk sgdisk mkswap readlink lsblk \
         btrfs xfs_growfs resize2fs \
         e2fsck btrfsck xfs_repair \
@@ -24,6 +24,7 @@ install() {
         mdadm cryptsetup dialog \
         pv curl xz \
         dmsetup
+    inst_multiple -o dolly
     if [[ "$(uname -m)" =~ s390 ]];then
         inst_multiple fdasd
     fi
