@@ -17,7 +17,6 @@
 #
 import re
 import os
-import pickle
 import logging
 import glob
 from collections import namedtuple
@@ -32,7 +31,6 @@ from kiwi.system.kernel import Kernel
 from kiwi.exceptions import (
     KiwiTargetDirectoryNotFound,
     KiwiConfigFileNotFound,
-    KiwiBootImageDumpError,
     KiwiDiskBootImageError
 )
 
@@ -47,9 +45,11 @@ class BootImageBase:
     :param string target_dir: target dir to store the initrd
     :param string root_dir: system image root directory
     :param list signing_keys: list of package signing keys
+    :param str target_arch: target architecture
     """
     def __init__(
-        self, xml_state, target_dir, root_dir=None, signing_keys=None
+        self, xml_state, target_dir, root_dir=None,
+        signing_keys=None, target_arch=None
     ):
         self.xml_state = xml_state
         self.target_dir = target_dir
@@ -57,6 +57,7 @@ class BootImageBase:
         self.boot_xml_state = None
         self.setup = None
         self.signing_keys = signing_keys
+        self.target_arch = target_arch
         self.boot_root_directory = root_dir
 
         if not os.path.exists(target_dir):
@@ -150,22 +151,6 @@ class BootImageBase:
         """
         pass
 
-    def dump(self, filename):
-        """
-        Pickle dump this instance to a file. If the object dump
-        is requested the destructor code will also be disabled
-        in order to preserve the generated data
-
-        :param string filename: file path name
-        """
-        try:
-            with open(filename, 'wb') as boot_image:
-                pickle.dump(self, boot_image)
-        except Exception as e:
-            raise KiwiBootImageDumpError(
-                'Failed to pickle dump boot image: %s' % format(e)
-            )
-
     def get_boot_names(self):
         """
         Provides kernel and initrd names for the boot image
