@@ -17,43 +17,49 @@
 #
 import re
 import logging
+from typing import List
+
 
 # project
+from kiwi.command import command_call_type
 from kiwi.command import Command
 from kiwi.utils.rpm_database import RpmDataBase
 from kiwi.utils.rpm import Rpm
 from kiwi.package_manager.base import PackageManagerBase
+from kiwi.system.root_bind import RootBind
 from kiwi.path import Path
-from kiwi.exceptions import KiwiRequestError
 from kiwi.defaults import Defaults
+from kiwi.repository.dnf import RepositoryDnf
+
+from kiwi.exceptions import KiwiRequestError
 
 log = logging.getLogger('kiwi')
 
 
 class PackageManagerMicroDnf(PackageManagerBase):
     """
-    ***Implements base class for installation/deletion of
-    packages and collections using microdnf***
+    **Implements Installation/Deletion of packages/collections with microdnf***
 
-    :param doct dnf_args: microdnf arguments from repository runtime configuration
-    :param dict command_env: microdnf command environment from repository runtime
+    :param doct dnf_args:
+        microdnf arguments from repository runtime configuration
+    :param dict command_env:
+        microdnf command environment from repository runtime
         configuration
     """
-    def post_init(self, custom_args=None):
+    def post_init(self, custom_args: List = []) -> None:
         """
         Post initialization method
 
         :param list custom_args: custom microdnf arguments
         """
+        self.repository: RepositoryDnf = self.repository
         self.custom_args = custom_args
-        if not custom_args:
-            self.custom_args = []
 
         runtime_config = self.repository.runtime_config()
         self.dnf_args = runtime_config['dnf_args']
         self.command_env = runtime_config['command_env']
 
-    def request_package(self, name):
+    def request_package(self, name: str) -> None:
         """
         Queue a package request
 
@@ -61,7 +67,7 @@ class PackageManagerMicroDnf(PackageManagerBase):
         """
         self.package_requests.append(name)
 
-    def request_collection(self, name):
+    def request_collection(self, name: str) -> None:
         """
         Queue a collection request
 
@@ -71,7 +77,7 @@ class PackageManagerMicroDnf(PackageManagerBase):
             'Group(%s) handling not yet supported for microdnf', name
         )
 
-    def request_product(self, name):
+    def request_product(self, name: str) -> None:
         """
         Queue a product request
 
@@ -81,7 +87,7 @@ class PackageManagerMicroDnf(PackageManagerBase):
         """
         pass
 
-    def request_package_exclusion(self, name):
+    def request_package_exclusion(self, name: str) -> None:
         """
         Queue a package exclusion(skip) request
 
@@ -89,7 +95,9 @@ class PackageManagerMicroDnf(PackageManagerBase):
         """
         self.exclude_requests.append(name)
 
-    def process_install_requests_bootstrap(self, root_bind=None):
+    def process_install_requests_bootstrap(
+        self, root_bind: RootBind = None
+    ) -> command_call_type:
         """
         Process package install requests for bootstrap phase (no chroot)
 
@@ -119,7 +127,7 @@ class PackageManagerMicroDnf(PackageManagerBase):
             ['bash', '-c', ' '.join(bash_command)], self.command_env
         )
 
-    def process_install_requests(self):
+    def process_install_requests(self) -> command_call_type:
         """
         Process package install requests for image phase (chroot)
 
@@ -127,19 +135,20 @@ class PackageManagerMicroDnf(PackageManagerBase):
 
         :rtype: namedtuple
         """
+        exclude_args = []
         if self.exclude_requests:
             # For DNF, excluding a package means removing it from
             # the solver operation. This is done by adding --exclude
             # to the command line. This means that if the package is
             # hard required by another package, it will break the transaction.
             for package in self.exclude_requests:
-                self.custom_args.append('--exclude=' + package)
+                exclude_args.append('--exclude=' + package)
         chroot_dnf_args = Path.move_to_root(
             self.root_dir, self.dnf_args
         )
         bash_command = [
             'chroot', self.root_dir, 'microdnf'
-        ] + chroot_dnf_args + self.custom_args + [
+        ] + chroot_dnf_args + self.custom_args + exclude_args + [
             'install'
         ] + self.package_requests
         self.cleanup_requests()
@@ -147,7 +156,7 @@ class PackageManagerMicroDnf(PackageManagerBase):
             ['bash', '-c', ' '.join(bash_command)], self.command_env
         )
 
-    def process_delete_requests(self, force=False):
+    def process_delete_requests(self, force: bool = False) -> command_call_type:
         """
         Process package delete requests (chroot)
 
@@ -191,7 +200,7 @@ class PackageManagerMicroDnf(PackageManagerBase):
                 self.command_env
             )
 
-    def update(self):
+    def update(self) -> command_call_type:
         """
         Process package update requests (chroot)
 
@@ -209,21 +218,23 @@ class PackageManagerMicroDnf(PackageManagerBase):
             self.command_env
         )
 
-    def process_only_required(self):
+    def process_only_required(self) -> None:
         """
         Setup package processing only for required packages
         """
         if '--setopt=install_weak_deps=0' not in self.custom_args:
             self.custom_args.append('--setopt=install_weak_deps=0')
 
-    def process_plus_recommended(self):
+    def process_plus_recommended(self) -> None:
         """
         Setup package processing to also include recommended dependencies.
         """
         if '--setopt=install_weak_deps=0' in self.custom_args:
             self.custom_args.remove('--setopt=install_weak_deps=0')
 
-    def match_package_installed(self, package_name, dnf_output):
+    def match_package_installed(
+        self, package_name: str, package_manager_output: str
+    ) -> bool:
         """
         Match expression to indicate a package has been installed
 
@@ -232,33 +243,43 @@ class PackageManagerMicroDnf(PackageManagerBase):
         be false positives due to sub package names starting with
         the same base package name
 
-        :param list package_list: list of all packages
-        :param str log_line: microdnf status line
+        :param str package_name: package_name
+        :param str package_manager_output: microdnf status line
 
-        :returns: match or None if there isn't any match
+        :returns: True|False
 
-        :rtype: match object, None
+        :rtype: bool
         """
-        return re.match(
-            '.*Installing  : ' + re.escape(package_name) + '.*', dnf_output
+        return bool(
+            re.match(
+                '.*Installing  : {0}.*'.format(re.escape(package_name)),
+                package_manager_output
+            )
         )
 
-    def match_package_deleted(self, package_name, dnf_output):
+    def match_package_deleted(
+        self, package_name: str, package_manager_output: str
+    ) -> bool:
         """
         Match expression to indicate a package has been deleted
 
-        :param list package_list: list of all packages
-        :param str log_line: microdnf status line
+        :param str package_name: package_name
+        :param str package_manager_output: microdnf status line
 
-        :returns: match or None if there isn't any match
+        :returns: True|False
 
-        :rtype: match object, None
+        :rtype: bool
         """
-        return re.match(
-            '.*Removing: ' + re.escape(package_name) + '.*', dnf_output
+        return bool(
+            re.match(
+                '.*Removing: {0}.*'.format(re.escape(package_name)),
+                package_manager_output
+            )
         )
 
-    def post_process_install_requests_bootstrap(self, root_bind=None):
+    def post_process_install_requests_bootstrap(
+        self, root_bind: RootBind = None
+    ) -> None:
         """
         Move the rpm database to the place as it is expected by the
         rpm package installed during bootstrap phase
@@ -269,7 +290,7 @@ class PackageManagerMicroDnf(PackageManagerBase):
         if rpmdb.has_rpm():
             rpmdb.set_database_to_image_path()
 
-    def clean_leftovers(self):
+    def clean_leftovers(self) -> None:
         """
         Cleans package manager related data not needed in the
         resulting image such as custom macros
