@@ -18,6 +18,7 @@
 import os
 import logging
 from collections import OrderedDict
+from typing import Dict
 from tempfile import NamedTemporaryFile
 
 # project
@@ -37,15 +38,18 @@ class Disk(DeviceProvider):
     :param object storage_provider: Instance of class based on DeviceProvider
     :param int start_sector: sector number
     """
-    def __init__(self, table_type, storage_provider, start_sector=None):
+    def __init__(
+        self, table_type: str, storage_provider: DeviceProvider,
+        start_sector: int = None
+    ):
         # bind the underlaying block device providing class instance
         # to this object (e.g loop) if present. This is done to guarantee
         # the correct destructor order when the device should be released.
         self.storage_provider = storage_provider
 
-        self.partition_map = {}
-        self.public_partition_id_map = {}
-        self.partition_id_map = {}
+        self.partition_map: Dict[str, str] = {}
+        self.public_partition_id_map: Dict[str, str] = {}
+        self.partition_id_map: Dict[str, str] = {}
         self.is_mapped = False
 
         self.partitioner = Partitioner.new(
@@ -54,7 +58,7 @@ class Disk(DeviceProvider):
 
         self.table_type = table_type
 
-    def get_device(self):
+    def get_device(self) -> Dict[str, MappedDevice]:
         """
         Names of partition devices
 
@@ -71,7 +75,7 @@ class Disk(DeviceProvider):
             )
         return device_map
 
-    def is_loop(self):
+    def is_loop(self) -> bool:
         """
         Check if storage provider is loop based
 
@@ -84,14 +88,14 @@ class Disk(DeviceProvider):
         """
         return self.storage_provider.is_loop()
 
-    def create_root_partition(self, mbsize):
+    def create_root_partition(self, mbsize: str):
         """
         Create root partition
 
         Populates kiwi_RootPart(id) and kiwi_BootPart(id) if no extra
         boot partition is requested
 
-        :param int mbsize: partition size
+        :param str mbsize: partition size NumberString or 'all_free'
         """
         self.partitioner.create('p.lxroot', mbsize, 't.linux')
         self._add_to_map('root')
@@ -101,19 +105,19 @@ class Disk(DeviceProvider):
         if 'kiwi_BootPart' not in self.public_partition_id_map:
             self._add_to_public_id_map('kiwi_BootPart')
 
-    def create_root_lvm_partition(self, mbsize):
+    def create_root_lvm_partition(self, mbsize: str):
         """
         Create root partition for use with LVM
 
         Populates kiwi_RootPart(id)
 
-        :param int mbsize: partition size
+        :param str mbsize: partition size NumberString or 'all_free'
         """
         self.partitioner.create('p.lxlvm', mbsize, 't.lvm')
         self._add_to_map('root')
         self._add_to_public_id_map('kiwi_RootPart')
 
-    def create_root_raid_partition(self, mbsize):
+    def create_root_raid_partition(self, mbsize: str):
         """
         Create root partition for use with MD Raid
 
@@ -121,14 +125,14 @@ class Disk(DeviceProvider):
         as the default raid device node at boot time which is
         configured to be kiwi_RaidDev(/dev/mdX)
 
-        :param int mbsize: partition size
+        :param str mbsize: partition size NumberString or 'all_free'
         """
         self.partitioner.create('p.lxraid', mbsize, 't.raid')
         self._add_to_map('root')
         self._add_to_public_id_map('kiwi_RootPart')
         self._add_to_public_id_map('kiwi_RaidPart')
 
-    def create_root_readonly_partition(self, mbsize):
+    def create_root_readonly_partition(self, mbsize: str):
         """
         Create root readonly partition for use with overlayfs
 
@@ -137,79 +141,79 @@ class Disk(DeviceProvider):
         should be the size of the squashfs filesystem in order to
         avoid wasting disk space
 
-        :param int mbsize: partition size
+        :param str mbsize: partition size NumberString or 'all_free'
         """
         self.partitioner.create('p.lxreadonly', mbsize, 't.linux')
         self._add_to_map('readonly')
         self._add_to_public_id_map('kiwi_ROPart')
 
-    def create_boot_partition(self, mbsize):
+    def create_boot_partition(self, mbsize: str):
         """
         Create boot partition
 
         Populates kiwi_BootPart(id)
 
-        :param int mbsize: partition size
+        :param str mbsize: partition size NumberString or 'all_free'
         """
         self.partitioner.create('p.lxboot', mbsize, 't.linux')
         self._add_to_map('boot')
         self._add_to_public_id_map('kiwi_BootPart')
 
-    def create_prep_partition(self, mbsize):
+    def create_prep_partition(self, mbsize: str):
         """
         Create prep partition
 
         Populates kiwi_PrepPart(id)
 
-        :param int mbsize: partition size
+        :param str mbsize: partition size NumberString or 'all_free'
         """
         self.partitioner.create('p.prep', mbsize, 't.prep')
         self._add_to_map('prep')
         self._add_to_public_id_map('kiwi_PrepPart')
 
-    def create_spare_partition(self, mbsize):
+    def create_spare_partition(self, mbsize: str):
         """
         Create spare partition for custom use
 
         Populates kiwi_SparePart(id)
 
-        :param int mbsize: partition size
+        :param str mbsize: partition size NumberString or 'all_free'
         """
         self.partitioner.create('p.spare', mbsize, 't.linux')
         self._add_to_map('spare')
         self._add_to_public_id_map('kiwi_SparePart')
 
-    def create_swap_partition(self, mbsize):
+    def create_swap_partition(self, mbsize: str):
         """
         Create swap partition
 
         Populates kiwi_SwapPart(id)
 
-        :param int mbsize: partition size
+        :param str mbsize: partition size NumberString or 'all_free'
         """
         self.partitioner.create('p.swap', mbsize, 't.swap')
         self._add_to_map('swap')
         self._add_to_public_id_map('kiwi_SwapPart')
 
-    def create_efi_csm_partition(self, mbsize):
+    def create_efi_csm_partition(self, mbsize: str):
         """
         Create EFI bios grub partition
 
         Populates kiwi_BiosGrub(id)
 
-        :param int mbsize: partition size
+        :param str mbsize: partition size NumberString or 'all_free'
         """
         self.partitioner.create('p.legacy', mbsize, 't.csm')
         self._add_to_map('efi_csm')
         self._add_to_public_id_map('kiwi_BiosGrub')
 
-    def create_efi_partition(self, mbsize):
+    def create_efi_partition(self, mbsize: str):
         """
         Create EFI partition
 
         Populates kiwi_EfiPart(id)
 
-        :param int mbsize: partition size
+        :param str mbsize: partition size NumberString or 'all_free'
         """
         self.partitioner.create('p.UEFI', mbsize, 't.efi')
         self._add_to_map('efi')
@@ -300,7 +304,7 @@ class Disk(DeviceProvider):
                 ['partprobe', self.storage_provider.get_device()]
             )
 
-    def get_public_partition_id_map(self):
+    def get_public_partition_id_map(self) -> Dict[str, str]:
         """
         Populated partition name to number map
         """
