@@ -16,13 +16,11 @@
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
 from typing import (
-    List, Optional, Any, Dict
+    List, Optional, Any, Dict, NamedTuple
 )
 import re
 import logging
 import copy
-import platform
-from collections import namedtuple
 from textwrap import dedent
 
 # project
@@ -41,28 +39,38 @@ from kiwi.exceptions import (
 
 log = logging.getLogger('kiwi')
 
-description_type = namedtuple(
-    'description_type', ['author', 'contact', 'specification']
+description_type = NamedTuple(
+    'description_type', [
+        ('author', str),
+        ('contact', str),
+        ('specification', str)
+    ]
 )
 
-package_type = namedtuple(
-    'package_type', ['packages_section', 'package_section']
+package_type = NamedTuple(
+    'package_type', [
+        ('packages_section', xml_parse.packages),
+        ('package_section', xml_parse.package)
+    ]
 )
 
-size_type = namedtuple(
-    'size_type', ['mbytes', 'additive']
+size_type = NamedTuple(
+    'size_type', [
+        ('mbytes', int),
+        ('additive', str)
+    ]
 )
 
-volume_type = namedtuple(
+volume_type = NamedTuple(
     'volume_type', [
-        'name',
-        'size',
-        'realpath',
-        'mountpoint',
-        'fullsize',
-        'label',
-        'attributes',
-        'is_root_volume'
+        ('name', str),
+        ('size', str),
+        ('realpath', str),
+        ('mountpoint', Optional[str]),
+        ('fullsize', bool),
+        ('label', Optional[str]),
+        ('attributes', list),
+        ('is_root_volume', bool)
     ]
 )
 
@@ -81,7 +89,7 @@ class XMLState:
     ):
         self.root_partition_uuid: Optional[str] = None
         self.root_filesystem_uuid: Optional[str] = None
-        self.host_architecture = platform.machine()
+        self.host_architecture = defaults.PLATFORM_MACHINE
         self.xml_data = xml_data
         self.profiles = self._used_profiles(profiles)
         self.build_type = self._build_type_section(
@@ -142,7 +150,7 @@ class XMLState:
         """
         return self.build_type.get_image()
 
-    def get_image_version(self) -> Optional[str]:
+    def get_image_version(self) -> str:
         """
         Image version from preferences section.
 
@@ -158,7 +166,7 @@ class XMLState:
             version = preferences.get_version()
             if version:
                 return version[0]
-        return None
+        return ''
 
     def get_initrd_system(self) -> str:
         """
@@ -1020,7 +1028,7 @@ class XMLState:
 
         :rtype: list
         """
-        modules = []
+        modules: List[str] = []
         installmedia = self.build_type.get_installmedia()
         if not installmedia:
             return modules
@@ -1370,6 +1378,12 @@ class XMLState:
                     # the attribute is handled
                     attributes.append('no-copy-on-write')
 
+                if volume.get_filesystem_check() is True:
+                    # by default filesystem check is switched off for any
+                    # filesystem except the rootfs. Thus only if filesystem
+                    # check is requested the attribute is handled
+                    attributes.append('enable-for-filesystem-check')
+
                 if '@root' in name:
                     # setup root volume, it takes an optional volume
                     # name if specified as @root=name and has no specific
@@ -1654,8 +1668,8 @@ class XMLState:
                 repository.set_package_gpgcheck(repo_package_gpgcheck)
 
     def add_repository(
-        self, repo_source: str, repo_type: str, repo_alias: str,
-        repo_prio: str, repo_imageinclude: bool = False,
+        self, repo_source: str, repo_type: str, repo_alias: str = None,
+        repo_prio: str = '', repo_imageinclude: bool = False,
         repo_package_gpgcheck: Optional[bool] = None
     ) -> None:
         """
